ProgressTrackerState class

Available extensions
Annotations
  • @artifact

Constructors

ProgressTrackerState({required int total, int completed = 0})
const

Properties

completed int
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
to → _a

Available on _d, provided by the $ProgressTrackerState extension

no setter
total int
final

Methods

copyWith({_9? total, _9? deltaTotal, _9? completed, _n resetCompleted = _F, _9? deltaCompleted}) → _d

Available on _d, provided by the $ProgressTrackerState extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() → _5

Available on _d, provided by the $ProgressTrackerState extension

toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited