RepositoryRecord mixin

Properties

coreVectorProgress ProgressTrackerState
no setter
distilledVectorProgress ProgressTrackerState
no setter
generation String
no setter
hashCode int
The hash code for this object.
no setterinherited
ingestionError String?
no setter
recordPath String
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

getSources() Stream<ChunkSource>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited