ChunkBucketSource class
- Inheritance
-
- Object
- ChunkSource
- ChunkBucketSource
- Available extensions
- Annotations
-
- @artifact
Constructors
- ChunkBucketSource({required String bucket, required String path})
-
const
Properties
- bucket → String
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- path → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- to → _a
-
Available on _f, provided by the $ChunkBucketSource extension
no setter - to → _a
-
Available on _e, provided by the $ChunkSource extension
no setter
Methods
-
copyWith(
{_7? bucket, _7? path}) → _f -
Available on _f, provided by the $ChunkBucketSource extension
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toMap(
) → _5 -
Available on _f, provided by the $ChunkBucketSource extension
-
toMap(
) → _5 -
Available on _e, provided by the $ChunkSource extension
-
toString(
) → String -
A string representation of this object.
inherited
-
writeTo(
File file) → Future< void> -
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited