ChunkStringSource class
- Inheritance
-
- Object
- ChunkSource
- ChunkStringSource
- Available extensions
- Annotations
-
- @artifact
Constructors
- ChunkStringSource({required String source})
-
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- source → String
-
final
- to → _a
-
Available on _e, provided by the $ChunkSource extension
no setter - to → _a
-
Available on _h, provided by the $ChunkStringSource extension
no setter
Methods
-
copyWith(
{_7? source}) → _h -
Available on _h, provided by the $ChunkStringSource extension
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toMap(
) → _5 -
Available on _e, provided by the $ChunkSource extension
-
toMap(
) → _5 -
Available on _h, provided by the $ChunkStringSource extension
-
toString(
) → String -
A string representation of this object.
inherited
-
writeTo(
File file) → Future< void> -
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited