TaskChunk class

Mixed-in types
  • ExecutableTask
Available extensions
Annotations
  • @artifact

Constructors

TaskChunk({required String taskId, required ChunkSource source, int maxChunkSize = 500, int maxPostOverlap = 100, int embedBatchSize = 25, int chunkBatchSize = 100, int? distillationFactor, int? lastChunk, bool chunkingFinished = false, required String destinationCollection, required String record, required String bucket, Map<String, dynamic> destinationMetadata = const {}})

Properties

bucket String
final
chunkBatchSize int
final
chunkCount int
no setter
chunkingFinished bool
getter/setter pair
destinationCollection String
final
destinationMetadata Map<String, dynamic>
final
distillationFactor int?
final
embedBatchSize int
final
hashCode int
The hash code for this object.
no setterinherited
lastChunk int?
getter/setter pair
maxChunkSize int
final
maxPostOverlap int
final
record String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
shouldScheduleDistillation bool
no setter
source ChunkSource
final
taskId String
final
to → _a

Available on _h, provided by the $TaskChunk extension

no setter

Methods

addChunk(Chunk chunk) Future<String>
copyWith({_7? taskId, _d? source, _9? maxChunkSize, _m resetMaxChunkSize = _F, _9? deltaMaxChunkSize, _9? maxPostOverlap, _m resetMaxPostOverlap = _F, _9? deltaMaxPostOverlap, _9? embedBatchSize, _m resetEmbedBatchSize = _F, _9? deltaEmbedBatchSize, _9? chunkBatchSize, _m resetChunkBatchSize = _F, _9? deltaChunkBatchSize, _9? distillationFactor, _m deleteDistillationFactor = _F, _9? deltaDistillationFactor, _9? lastChunk, _m deleteLastChunk = _F, _9? deltaLastChunk, _m? chunkingFinished, _m resetChunkingFinished = _F, _7? destinationCollection, _7? record, _7? bucket, _t? destinationMetadata, _m resetDestinationMetadata = _F}) → _h

Available on _h, provided by the $TaskChunk extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() → _5

Available on _h, provided by the $TaskChunk extension

toString() String
A string representation of this object.
inherited
workOnTask(TaskExecutionContext context) Future<void>
override

Operators

operator ==(Object other) bool
The equality operator.
inherited