TaskEmbed class

Mixed-in types
  • ExecutableTask
Available extensions
Annotations
  • @artifact

Constructors

TaskEmbed({required RecordLocation recordLocation, required String taskId, required String collection, required List<String> chunks, required String bucket, required int lod})

Properties

bucket String
final
chunks List<String>
final
collection String
final
hashCode int
The hash code for this object.
no setterinherited
lod int
final
recordLocation RecordLocation
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
taskId String
final
to → _a

Available on _l, provided by the $TaskEmbed extension

no setter

Methods

copyWith({_i? recordLocation, _7? taskId, _7? collection, _6? chunks, _6? appendChunks, _6? removeChunks, _7? bucket, _9? lod, _9? deltaLod}) → _l

Available on _l, provided by the $TaskEmbed extension

getContent(String doc) Future<Content>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setVector(String doc, List<double> vector) Future<void>
toMap() → _5

Available on _l, provided by the $TaskEmbed extension

toString() String
A string representation of this object.
inherited
workOnTask(TaskExecutionContext context) Future<void>
override

Operators

operator ==(Object other) bool
The equality operator.
inherited