TaskEmbed class
- Mixed-in types
-
- ExecutableTask
- Available extensions
- Annotations
-
- @artifact
Constructors
Properties
- bucket → String
-
final
-
chunks
→ List<
String> -
final
- collection → String
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- taskId → String
-
final
- to → _a
-
Available on _j, provided by the $TaskEmbed extension
no setter
Methods
-
copyWith(
{_7? taskId, _7? collection, _6? chunks, _6? appendChunks, _6? removeChunks, _7? bucket}) → _j -
Available on _j, provided by the $TaskEmbed extension
-
getContent(
String doc) → Future< Content> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
setVector(
String doc, List< double> vector) → Future<void> -
toMap(
) → _5 -
Available on _j, provided by the $TaskEmbed extension
-
toString(
) → String -
A string representation of this object.
inherited
-
workOnTask(
TaskExecutionContext context) → Future< void> -
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited